==> meteor-react-materializecss-1.0.27.tgz: package/src/i18n/en.js <==
export default {
    "_locale": "en-GB",
    "simpleSchema": {
        "required": "{{label}} is mandatory",
        "minString": "{{label}} must have at least {{min}} characters",
        "maxString": "{{label}} cannot exceed {{max}} characters",
        "minNumber": "{{label}} must be at least {{min}}",
        "maxNumber": "{{label}} must not exceed {{max}}",
        "minNumberExclusive": "{{label}} must be greater than {{min}}",
        "maxNumberExclusive": "{{label}} must be less than {{max}}",
        "minDate": "{{label}} must be on the same day or after {{min}}",
        "maxDate": "{{label}} must be after {{max}}",
        "badDate": "{{label}} is not a valid date",
        "minCount": "You must enter at least {{minCount}} values",
        "maxCount": "You cannot enter more than {{maxCount}} values",
        "noDecimal": "{{label}} must be an integer",
        "notAllowed": "{{value}} is not an allowed value",
        "expectedType": "{{label}} must be of type {{dataType}}",
        "expectedString": "{{label}} must be text",
        "expectedNumber": "{{label}} must be a number",
        "expectedBoolean": "{{label}} must be a logical value",
        "expectedArray": "{{label}} must be a field",
        "expectedObject": "{{label}} must be an object",
        "expectedConstructor": "{{label}} must be {{type}}",
        "keyNotInSchema": "{{key}} is not allowed by the scheme",
        "idNotFound": "ID {{label}} not found",
        "wrongUnit": "Wrong {{label}} {{value}}",
        "wrongRola": "{{label}} je nesprávna",
        "wrongConfirmPassw": "Password and password check are not the same",
        "regEx": {
            "msg": "{{label}} failed validation of regular expression",
            "email": "{{label}} must be a valid email address",
            "weakEmail": "{{label}} must be a valid email address",
            "domain": "{{label}} must be a valid domain",
            "weakDomain": "{{label}} must be a valid domain",
            "ip": "{{label}} must be a valid IPv4 or IPv6 address",
            "ipV4": "{{label}} must be a valid IPv4 address",
            "ipV6": "{{label}} must be a valid IPv6 address",
            "url": "{{label}} must be a valid URL",
            "id": "{{label}} must be a valid alphanumeric ID"
        }
    },
    "messages": {
        "back": "back",
        "search": "Search",
        "save": "Save",
        "save_error": "Save error",
        "error": "Error",
        "no_connection": "There is no internet connection!",
        "records_count": "number of records",
        "yes": "Yes",
        "no": "No",
        "delete_title": "Delete record",
        "delete": "Delete",
        "delete_error": "Delete error",
        "insert": "Insert",
        "show": "Show",
        "cancel": "Cancel",
        "select_columns": "Select columns"
    }
}

==> meteor-react-materializecss-1.0.32.tgz: package/src/i18n/en.js <==
export default {
    "_locale": "en-GB",
    "simpleSchema": {
        "required": "{{label}} is mandatory",
        "minString": "{{label}} must have at least {{min}} characters",
        "maxString": "{{label}} cannot exceed {{max}} characters",
        "minNumber": "{{label}} must be at least {{min}}",
        "maxNumber": "{{label}} must not exceed {{max}}",
        "minNumberExclusive": "{{label}} must be greater than {{min}}",
        "maxNumberExclusive": "{{label}} must be less than {{max}}",
        "minDate": "{{label}} must be on the same day or after {{min}}",
        "maxDate": "{{label}} must be after {{max}}",
        "badDate": "{{label}} is not a valid date",
        "minCount": "You must enter at least {{minCount}} values",
        "maxCount": "You cannot enter more than {{maxCount}} values",
        "noDecimal": "{{label}} must be an integer",
        "notAllowed": "{{value}} is not an allowed value",
        "expectedType": "{{label}} must be of type {{dataType}}",
        "expectedString": "{{label}} must be text",
        "expectedNumber": "{{label}} must be a number",
        "expectedBoolean": "{{label}} must be a logical value",
        "expectedArray": "{{label}} must be a field",
        "expectedObject": "{{label}} must be an object",
        "expectedConstructor": "{{label}} must be {{type}}",
        "keyNotInSchema": "{{key}} is not allowed by the scheme",
        "idNotFound": "ID {{label}} not found",
        "wrongUnit": "Wrong {{label}} {{value}}",
        "wrongRola": "{{label}} je nesprávna",
        "wrongConfirmPassw": "Password and password check are not the same",
        "regEx": {
            "msg": "{{label}} failed validation of regular expression",
            "email": "{{label}} must be a valid email address",
            "weakEmail": "{{label}} must be a valid email address",
            "domain": "{{label}} must be a valid domain",
            "weakDomain": "{{label}} must be a valid domain",
            "ip": "{{label}} must be a valid IPv4 or IPv6 address",
            "ipV4": "{{label}} must be a valid IPv4 address",
            "ipV6": "{{label}} must be a valid IPv6 address",
            "url": "{{label}} must be a valid URL",
            "id": "{{label}} must be a valid alphanumeric ID"
        }
    },
    "messages": {
        "back": "back",
        "search": "Search",
        "save": "Save",
        "save_error": "Save error",
        "error": "Error",
        "no_connection": "There is no internet connection!",
        "records_count": "number of records",
        "yes": "Yes",
        "no": "No",
        "delete_title": "Delete record",
        "delete": "Delete",
        "delete_error": "Delete error",
        "insert": "Insert",
        "show": "Show",
        "cancel": "Cancel",
        "select_columns": "Select columns",
        "view": "View"
    }
}
